#!/bin/sh
# Copyright (c) 2024-2025 Maytham Alsudany <maytha8thedev@gmail.com>
# Licensed under Expat; see debian/copyright for more info.

set -e

ROOT_IMPORTPATH="github.com/Azure/azure-sdk-for-go"

TEMPDIR=$(realpath "debian/build/link-modules-tmp")
mkdir -p "$TEMPDIR"

cd "debian/build/src/$ROOT_IMPORTPATH"

# Unneeded parts
#find . -mindepth 1 -maxdepth 1 -type d -not -name sdk | while read -r DIR; do
#  rm -r "$DIR"
#  echo "[debian/scripts/prepare-modules.sh] Removed $DIR"
#done

# sdk modules with deps not in Debian
rm -r sdk/samples
rm -r sdk/messaging/azeventhubs
rm -r sdk/messaging/azservicebus/internal/stress
rm -r sdk/ai/azopenaiextensions
rm -rf eng/tools/

# Remove testdata
find sdk -type d -name testdata | while read -r DIR; do
  rm -r "$DIR"
  echo "[debian/scripts/prepare-modules.sh] Removed $DIR"
done

# Unneeded binaries
#grep -r "package main" sdk -l | xargs dirname | sort -u | while read -r DIR; do
#  rm -r "$DIR"
#  echo "[debian/scripts/prepare-modules.sh] Removed $DIR"
#done

# Fix package-contains-vcs-control-file lintian warning
find . -type f -name .gitignore -or -name .gitattributes -delete

# Remove anything that isn't code
find . -type f -not \( -name "*.go" -or -name "go.mod" \) -delete

find sdk/ -type f -name 'go.mod' | xargs dirname | while read -r MODULE; do

  IMPORTPATH="$(grep -E "^module $ROOT_IMPORTPATH/\S+\$" "$MODULE/go.mod" | cut -c42-)"

#  if [ -z "$IMPORTPATH" ]; then
#    rm -r "$MODULE"
#    echo "[debian/scripts/prepare-modules.sh] Removed $MODULE"
#    continue
#  fi

  if [ "$MODULE" != "$IMPORTPATH" ]; then

    TEMPLOC="$TEMPDIR/$(basename "$MODULE")"
    mv "$MODULE" "$TEMPLOC"
    mkdir -p "$(dirname $IMPORTPATH)"
    mv "$TEMPLOC" "$IMPORTPATH"

    echo "[debian/scripts/prepare-modules.sh] Moved $MODULE -> $IMPORTPATH"

  fi

done

rm -rf "$TEMPDIR"
